@@ -230,7 +230,7 @@ startarg_othercontinuous_actuar_family <- function(x, distr)
                   shape3=taustar, scale=thetahat)
   }else
     stop(paste0("Unknown starting values for distribution ", distr, "."))
-  
+  start <- cutshapeparam(start)
   return(start)
 }
 
@@ -367,6 +367,7 @@ startarg_fellerpareto_family <- function(x, distr)
     if (any(x < 0)) 
       stop("values must be positive to fit a inverse Burr distribution")
     start <- startarg_fellerpareto_family(1/x, "burr")
+    start$scale <- 1/start$scale
   }else if(distr == "pareto4")
   {
     muhat <- murel(x)
@@ -421,13 +422,13 @@ startarg_fellerpareto_family <- function(x, distr)
     q3 <- quantile(x, probs=3/4, na.rm=TRUE)
     thetahat <- as.numeric(thetarelP4(alphastar, gammastar, q1, q3))
     alphahat <- alpharelP4(x, mustar, thetahat, gammastar)
-    
     start <- list(shape=alphahat, scale=thetahat)
   }else if (distr == "invpareto")
   {
     if (any(x < 0)) 
       stop("values must be positive to fit a inverse Pareto  distribution")
     start <- startarg_fellerpareto_family(1/x, "pareto")
+    start$scale <- 1/start$scale
   }else if (distr == "llogis")
   {
     if (any(x < 0)) 
@@ -449,8 +450,10 @@ startarg_fellerpareto_family <- function(x, distr)
     if (any(x < 0)) 
       stop("values must be positive to fit a inverse paralogistic  distribution")
     start <- startarg_fellerpareto_family(1/x, "paralogis")
+    start$scale <- 1/start$scale
   }else
     stop("wrong distr")
+  start <- cutshapeparam(start)
   return(start)
 }
 
@@ -481,7 +484,7 @@ startarg_transgamma_family <- function(x, distr)
     if(v > 0)
     {
       alphahat <- m^2/v
-      thetahat <- m/v
+      thetahat <- v/m
     }else #exponential case
     {
       alphahat <- 1 
@@ -515,6 +518,7 @@ startarg_transgamma_family <- function(x, distr)
     start <- list(rate=1/mean(x))
   }else
     stop("wrong distr")
+  start <- cutshapeparam(start)
   return(start)
 }
 
@@ -529,6 +533,7 @@ startarg_invtransgamma_family <- function(x, distr)
     if (any(x < 0)) 
       stop("values must be positive to fit an inverse trans-gamma distribution")
     start <- startarg_transgamma_family(1/x, "trgamma")
+    start$scale <- 1/start$scale
   }else if (distr == "invgamma")
   {
     if (any(x < 0)) 
@@ -554,7 +559,26 @@ startarg_invtransgamma_family <- function(x, distr)
     if (any(x < 0)) 
       stop("values must be positive to fit an inverse exponential distribution")
     start <- startarg_transgamma_family(1/x, "exp")
+    start$rate <- 1/start$rate
   }else
     stop("wrong distr")
+  start <- cutshapeparam(start)
   return(start)
-}
\ No newline at end of file
+}
+
+cutshapeparam <- function(x, minval=.Machine$double.eps^(1/3), maxval=1e2)
+{
+  idshape <- grep("shape", names(x))
+  if(length(idshape) > 0)
+  {
+    x <- unlist(x)
+    x[idshape] <- pmin(x[idshape], maxval) #ceiling
+    x[idshape] <- pmax(x[idshape], minval) #floor
+    if(sum(x[idshape]) > maxval) #scale down
+      x[idshape] <- x[idshape]/2
+    x <- as.list(x)
+  }
+  x
+}
+
+
