@@ -1,5 +1,5 @@
-library(fitdistrplus)
-library(actuar)
+require("fitdistrplus")
+require("actuar")
 
 set.seed(1234)
 
@@ -18,31 +18,32 @@ fitdistrplus:::startarg_fellerpareto_family(x, "pareto")
 
 fitdistrplus:::startarg_fellerpareto_family(x, "llogis")
 
-fitdist(x, "pareto4")
-fitdist(x, "pareto3")
-fitdist(x, "pareto2", lower=0)
-fitdist(x, "pareto1", lower=0)
-fitdist(x, "pareto", lower=0)
+eps <- 1e-3
+fitdist(x, "pareto4", control=list(trace=1), lower=eps, optim="L-BFGS-B")
+fitdist(x, "pareto3", lower=eps, optim="L-BFGS-B")
+#fitdist(x, "pareto2", lower=eps, optim="L-BFGS-B")
+#fitdist(x, "pareto1", lower=eps, optim="L-BFGS-B")
+#fitdist(x, "pareto", lower=eps, optim="L-BFGS-B")
 
-fitdist(x, "llogis", lower=0)
+fitdist(x, "llogis", lower=eps, optim="L-BFGS-B")
 
 
 fitdistrplus:::startarg_fellerpareto_family(x, "fpareto")
 
-fitdist(x, "fpareto", lower=0)
+fitdist(x, "fpareto", lower=eps, optim="L-BFGS-B")
 
 fitdistrplus:::startarg_fellerpareto_family(x-1, "trbeta")
 
-fitdist(x-1, "trbeta", lower=0)
+fitdist(x-1, "trbeta", lower=eps, optim="L-BFGS-B")
 
 
 fitdistrplus:::startarg_fellerpareto_family(x-1, "genpareto")
 
-fitdist(x-1, "genpareto", lower=0)
+fitdist(x-1, "genpareto", lower=eps, optim="L-BFGS-B")
 
 fitdistrplus:::startarg_fellerpareto_family(x-1, "paralogis")
 
-fitdist(x-1, "paralogis", lower=0)
+fitdist(x-1, "paralogis", lower=eps, optim="L-BFGS-B")
 
 
 x <- rfpareto(n, 0, 1, 2, 2, scale=2)
